@@ -376,7 +376,7 @@ int32_t SPVM__Digest__MD5__md5(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_data = stack[0].oval;
   
   if (!obj_data) {
-    return env->die(env, stack, "The $data must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$data must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   data = (unsigned char *)env->get_chars(env, stack, obj_data);
@@ -399,7 +399,7 @@ int32_t SPVM__Digest__MD5__md5_hex(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_data = stack[0].oval;
   
   if (!obj_data) {
-    return env->die(env, stack, "The $data must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$data must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   data = (unsigned char *)env->get_chars(env, stack, obj_data);
@@ -420,7 +420,7 @@ int32_t SPVM__Digest__MD5__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_self = env->new_object_by_name(env, stack, "Digest::MD5", &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
-  MD5_CTX* ctx = env->new_memory_stack(env, stack, sizeof(MD5_CTX));
+  MD5_CTX* ctx = env->new_memory_block(env, stack, sizeof(MD5_CTX));
   
   MD5Init(ctx);
   
@@ -446,7 +446,7 @@ int32_t SPVM__Digest__MD5__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
   MD5_CTX* ctx = env->get_pointer(env, stack, obj_ctx);
   assert(ctx);
   
-  env->free_memory_stack(env, stack, ctx);
+  env->free_memory_block(env, stack, ctx);
   
   return 0;
 }
@@ -459,7 +459,7 @@ int32_t SPVM__Digest__MD5__add(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_data = stack[1].oval;
   
   if (!obj_data) {
-    return env->die(env, stack, "The $data must be defined", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "$data must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   const char* data = (unsigned char *)env->get_chars(env, stack, obj_data);
